@@ -52,10 +52,19 @@ INSTALL_LIBS_ENDPOINT = ("POST", "api/2.0/libraries/install")
 UNINSTALL_LIBS_ENDPOINT = ("POST", "api/2.0/libraries/uninstall")
 
 LIST_JOBS_ENDPOINT = ("GET", "api/2.1/jobs/list")
+LIST_PIPELINES_ENDPOINT = ("GET", "/api/2.0/pipelines")
 
 WORKSPACE_GET_STATUS_ENDPOINT = ("GET", "api/2.0/workspace/get-status")
 
-RUN_LIFE_CYCLE_STATES = ["PENDING", "RUNNING", "TERMINATING", "TERMINATED", "SKIPPED", "INTERNAL_ERROR"]
+RUN_LIFE_CYCLE_STATES = [
+    "PENDING",
+    "RUNNING",
+    "TERMINATING",
+    "TERMINATED",
+    "SKIPPED",
+    "INTERNAL_ERROR",
+    "QUEUED",
+]
 
 SPARK_VERSIONS_ENDPOINT = ("GET", "api/2.0/clusters/spark-versions")
 
@@ -75,11 +84,9 @@ class RunState:
         """True if the current state is a terminal state."""
         if self.life_cycle_state not in RUN_LIFE_CYCLE_STATES:
             raise AirflowException(
-                (
-                    "Unexpected life cycle state: {}: If the state has "
-                    "been introduced recently, please check the Databricks user "
-                    "guide for troubleshooting information"
-                ).format(self.life_cycle_state)
+                f"Unexpected life cycle state: {self.life_cycle_state}: If the state has "
+                "been introduced recently, please check the Databricks user "
+                "guide for troubleshooting information"
             )
         return self.life_cycle_state in ("TERMINATED", "SKIPPED", "INTERNAL_ERROR")
 
@@ -209,6 +216,67 @@ class DatabricksHook(BaseDatabricksHook):
         else:
             return matching_jobs[0]["job_id"]
 
+    def list_pipelines(
+        self, batch_size: int = 25, pipeline_name: str | None = None, notebook_path: str | None = None
+    ) -> list[dict[str, Any]]:
+        """
+        Lists the pipelines in Databricks Delta Live Tables.
+
+        :param batch_size: The limit/batch size used to retrieve pipelines.
+        :param pipeline_name: Optional name of a pipeline to search. Cannot be combined with path.
+        :param notebook_path: Optional notebook of a pipeline to search. Cannot be combined with name.
+        :return: A list of pipelines.
+        """
+        has_more = True
+        next_token = None
+        all_pipelines = []
+        filter = None
+        if pipeline_name and notebook_path:
+            raise AirflowException("Cannot combine pipeline_name and notebook_path in one request")
+
+        if notebook_path:
+            filter = f"notebook='{notebook_path}'"
+        elif pipeline_name:
+            filter = f"name LIKE '{pipeline_name}'"
+        payload: dict[str, Any] = {
+            "max_results": batch_size,
+        }
+        if filter:
+            payload["filter"] = filter
+
+        while has_more:
+            if next_token:
+                payload["page_token"] = next_token
+            response = self._do_api_call(LIST_PIPELINES_ENDPOINT, payload)
+            pipelines = response.get("statuses", [])
+            all_pipelines += pipelines
+            if "next_page_token" in response:
+                next_token = response["next_page_token"]
+            else:
+                has_more = False
+
+        return all_pipelines
+
+    def find_pipeline_id_by_name(self, pipeline_name: str) -> str | None:
+        """
+        Finds pipeline id by its name. If multiple pipelines with the same name, raises AirflowException.
+
+        :param pipeline_name: The name of the pipeline to look up.
+        :return: The pipeline_id as a GUID string or None if no pipeline was found.
+        """
+        matching_pipelines = self.list_pipelines(pipeline_name=pipeline_name)
+
+        if len(matching_pipelines) > 1:
+            raise AirflowException(
+                f"There are more than one job with name {pipeline_name}. "
+                "Please delete duplicated pipelines first"
+            )
+
+        if not pipeline_name:
+            return None
+        else:
+            return matching_pipelines[0]["pipeline_id"]
+
     def get_run_page_url(self, run_id: int) -> str:
         """
         Retrieves run_page_url.
